==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/pt_PT.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Não foi possível obter as senhas solicitadas. Verifique se o código e o segredo da sua app estão corretos.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Não foi possível obter as senhas de acesso. Verifique se o código e o segredo da sua app estão corretos.",
    "Please provide a valid app key and secret." : "Por favor, indique um código e segredo de app válidos.",
    "Step 1 failed. Exception: %s" : "Passo 1 falhou. Exceção: %s",
    "Step 2 failed. Exception: %s" : "Passo 2 falhou. Exceção: %s",
    "External storage" : "Armazenamento Externo",
    "Storage with id \"%i\" not found" : "Não foi encontrado o armazenamento com a id. \"%i\"",
    "Invalid backend or authentication mechanism class" : "Parâmetros do mecanismo de autenticação inválidos",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Objectstore proibido",
    "Invalid storage backend \"%s\"" : "Backend de armazenamento inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido utilizar a interface \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido utilizar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros backend insatisfeitos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros do mecanismo de autenticação inválidos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Armazenamento com id \"%i\" não é editável pelo utilizador",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Grant access" : "Conceder acesso",
    "Access granted" : "Acesso autorizado",
    "Error configuring OAuth1" : "Erro de configuração OAuth1",
    "Error configuring OAuth2" : "Erro de configuração OAuth2",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar chave par",
    "Enable encryption" : "Ative a encriptação",
    "Enable previews" : "Ative as pré-visualizações",
    "Enable sharing" : "Ativar partilha",
    "Check for changes" : "Verifique as suas alterações",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez em cada acesso direto",
    "All users. Type to select user or group." : "Todos os utilizadores. Digite para selecionar o utilizador ou grupo.",
    "(group)" : "(grupo)",
    "Admin defined" : "Administrador definido",
    "Saved" : "Guardado",
    "Empty response from the server" : "Resposta vazia a partir do servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Não foi possível aceder. Por favor, faça logout e login para ativar este ponto de montagem",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Não foi possível recolher a informação do servidor ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Não foi possível conseguir a lista de pontos de montagem externos: {type}",
    "There was an error with message: " : "Houve um erro com a mensagem:",
    "External mount error" : "Erro de montagem externa",
    "external-storage" : "Armazenamento Externo",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Não foi possível conseguir a lista de pontos de montagem Windows na rede: resposta vazia do servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alguns dos pontos de montagem externos configurados não estão conectados. Por favor, clique na fila vermelha para mais informação",
    "Please enter the credentials for the {mount} mount" : "Por favor, introduza as credenciais para {mount}",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Credentials saved" : "Credenciais guardadas",
    "Credentials saving failed" : "Falha ao salvar credenciais",
    "Credentials required" : "Credenciais necessárias",
    "Save" : "Guardar",
    "Access key" : "Código de acesso",
    "Secret key" : "Código secreto",
    "Builtin" : "Integrado",
    "None" : "Nenhum",
    "OAuth1" : "OAuth1",
    "App key" : "Chave da App",
    "App secret" : "Segredo da app",
    "OAuth2" : "OAuth2",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente\\\\",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome do locatário",
    "Identity endpoint URL" : "Identidade URL endpoint",
    "Rackspace" : "Rackspace",
    "API key" : "Chave API",
    "Username and password" : "Nome de utilizador e palavra-passe",
    "Log-in credentials, save in session" : "Credenciais de login, guardar na sessão",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota ",
    "Secure https://" : "https:// Seguro",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Anfitrião",
    "Secure ftps://" : "ftps:// Seguro",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Localização:",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP com login por chave secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartilhar",
    "Domain" : "Domínio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizando o início de sessão OC",
    "Username as share" : "Nome de utilizador como partilha",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Pedido expira (segundos)",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte cURL no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte FTP no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O cliente\"%s\" não está instalado. Não é possível montar \"%s\" . Peça ao seu administrador para instalar.",
    "No external storage configured" : "Sem armazenamentos externos configurados",
    "You can add external storages in the personal settings" : "Pode adicionar armazenamentos externos nas definições pessoais",
    "Name" : "Nome",
    "Storage type" : "Tipo de Armazenamento",
    "Scope" : "Âmbito",
    "External Storage" : "Armazenamento Externo",
    "Folder name" : "Nome da pasta",
    "Authentication" : "Autenticação",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Add storage" : "Adicionar armazenamento",
    "Advanced settings" : "Definições avançadas",
    "Delete" : "Apagar",
    "Allow users to mount external storage" : "Permitir que os utilizadores montem armazenamento externo",
    "Allow users to mount the following external storage" : "Permitir que os utilizadores montem o seguinte armazenamento externo",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alguns dos pontos de montagem externos configurados não estão conectados. Por favor, clique na fila vermelha para mais informação"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/pt_PT.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Não foi possível obter as senhas solicitadas. Verifique se o código e o segredo da sua app estão corretos.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Não foi possível obter as senhas de acesso. Verifique se o código e o segredo da sua app estão corretos.",
    "Please provide a valid app key and secret." : "Por favor, indique um código e segredo de app válidos.",
    "Step 1 failed. Exception: %s" : "Passo 1 falhou. Exceção: %s",
    "Step 2 failed. Exception: %s" : "Passo 2 falhou. Exceção: %s",
    "External storage" : "Armazenamento Externo",
    "Dropbox App Configuration" : "Configuração da aplicação Dropbox",
    "Google Drive App Configuration" : "Configuração da aplicação Google Drive",
    "Personal" : "Pessoal",
    "System" : "Sistema",
    "Grant access" : "Conceder acesso",
    "Error configuring OAuth1" : "Erro ao configurar OAuth1",
    "Error configuring OAuth2" : "Erro ao configurar OAuth2",
    "Generate keys" : "Gerar chaves",
    "Error generating key pair" : "Erro ao gerar chave par",
    "All users. Type to select user or group." : "Todos os utilizadores. Digite para selecionar o utilizador ou grupo.",
    "(group)" : "(grupo)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibilidade com a codificação NFD Mac (lenta)",
    "Admin defined" : "Administrador definido",
    "Saved" : "Guardado",
    "Empty response from the server" : "Resposta vazia a partir do servidor",
    "Couldn't access. Please logout and login to activate this mount point" : "Não foi possível aceder. Por favor, faça logout e login para ativar este ponto de montagem",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Não foi possível recolher a informação do servidor ownCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Não foi possível conseguir a lista de pontos de montagem externos: {type}",
    "There was an error with message: " : "Houve um erro com a mensagem:",
    "External mount error" : "Erro de montagem externa",
    "external-storage" : "armazenamento externo",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Não foi possível conseguir a lista de pontos de montagem Windows na rede: resposta vazia do servidor",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Alguns dos pontos de montagem externos configurados não estão conectados. Por favor, clique na fila vermelha para mais informação",
    "Please enter the credentials for the {mount} mount" : "Por favor, introduza as credenciais para {mount}",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Credentials saved" : "Credenciais guardadas",
    "Credentials saving failed" : "Falha ao guardar as credenciais",
    "Credentials required" : "Credenciais necessárias",
    "Save" : "Guardar",
    "Storage with id \"%i\" not found" : "Não foi encontrado o armazenamento com a id. \"%i\"",
    "Invalid backend or authentication mechanism class" : "Parâmetros do mecanismo de autenticação inválidos",
    "Invalid mount point" : "Ponto de montagem inválido",
    "Objectstore forbidden" : "Objectstore proibido",
    "Invalid storage backend \"%s\"" : "Backend de armazenamento inválido \"%s\"",
    "Not permitted to use backend \"%s\"" : "Não é permitido utilizar a interface \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Não é permitido utilizar o mecanismo de autenticação \"%s\"",
    "Unsatisfied backend parameters" : "Parâmetros backend insatisfeitos",
    "Unsatisfied authentication mechanism parameters" : "Parâmetros do mecanismo de autenticação inválidos",
    "Insufficient data: %s" : "Dados insuficientes: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Armazenamento com id \"%i\" não é editável pelo utilizador",
    "Access key" : "Chave de acesso",
    "Secret key" : "Código secreto",
    "Builtin" : "Integrado",
    "None" : "Nenhum",
    "OAuth1" : "OAuth1",
    "App key" : "Chave da App",
    "App secret" : "Segredo da app",
    "OAuth2" : "OAuth2",
    "Client ID" : "Id. do Cliente",
    "Client secret" : "Segredo do cliente\\\\",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Nome do locatário",
    "Identity endpoint URL" : "Identidade URL endpoint",
    "Rackspace" : "Rackspace",
    "API key" : "Chave API",
    "Username and password" : "Nome de utilizador e palavra-passe",
    "Log-in credentials, save in session" : "Credenciais de login, guardar na sessão",
    "RSA public key" : "Chave pública RSA",
    "Public key" : "Chave pública",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Nome do Anfitrião",
    "Port" : "Porta",
    "Region" : "Região",
    "Enable SSL" : "Ativar SSL",
    "Enable Path Style" : "Ativar Estilo do Caminho",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Subpasta remota ",
    "Secure https://" : "https:// Seguro",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Anfitrião",
    "Secure ftps://" : "ftps:// Seguro",
    "Google Drive" : "Google Drive",
    "Local" : "Local",
    "Location" : "Localização:",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP com login por chave secreta",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Compartilhar",
    "Domain" : "Domínio",
    "SMB / CIFS using OC login" : "SMB / CIFS utilizando o início de sessão OC",
    "Username as share" : "Nome de utilizador como partilha",
    "OpenStack Object Storage" : "Armazenamento de Objetos OpenStack",
    "Service name" : "Nome do serviço",
    "Request timeout (seconds)" : "Pedido expira (segundos)",
    "<b>Note:</b> " : "<b>Nota:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte cURL no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O suporte FTP no PHP não está activo ou instalado. Não é possível montar %s. Peça ao seu administrador para instalar.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Aviso:</b> O cliente\"%s\" não está instalado. Não é possível montar \"%s\" . Peça ao seu administrador para instalar.",
    "No external storage configured" : "Sem armazenamentos externos configurados",
    "You can add external storages in the personal settings" : "Pode adicionar armazenamentos externos nas definições pessoais",
    "Name" : "Nome",
    "Storage type" : "Tipo de Armazenamento",
    "Scope" : "Âmbito",
    "Enable encryption" : "Activar encriptação",
    "Enable previews" : "Ativar pré-visualizações",
    "Enable sharing" : "Ativar partilha",
    "Check for changes" : "Verificar se há alterações",
    "Never" : "Nunca",
    "Once every direct access" : "Uma vez em cada acesso direto",
    "External Storage" : "Armazenamento Externo",
    "Folder name" : "Nome da pasta",
    "Authentication" : "Autenticação",
    "Configuration" : "Configuração",
    "Available for" : "Disponível para ",
    "Add storage" : "Adicionar armazenamento",
    "Advanced settings" : "Definições avançadas",
    "Delete" : "Apagar",
    "Allow users to mount external storage" : "Permitir que os utilizadores montem armazenamento externo",
    "Allow users to mount the following external storage" : "Permitir que os utilizadores montem o seguinte armazenamento externo"
},
"nplurals=2; plural=(n != 1);");
